4.26. umbra.globals.constants — Umbra 1.0.9 documentation

# 4.26. umbra.globals.constants

constants.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines Umbra package default constants through the `Constants` class.

Others:

## 4.26.1. Classes

class `umbra.globals.constants.` `Constants`

  Defines Umbra package default constants.

  `applicationName` = u'Umbra'

    Parameters: | applicationName (unicode) – Package Application name.

  `majorVersion` = u'1'

    Parameters: | majorVersion (unicode) – Package major version.

  `minorVersion` = u'0'

    Parameters: | minorVersion (unicode) – Package minor version.

  `changeVersion` = u'9'

    Parameters: | changeVersion (unicode) – Package change version.

  `version` = u'1.0.9'

    Parameters: | version (unicode) – Package version.

  `logger` = u'Umbra_Logger'

    Parameters: | logger (unicode) – Package logger name.

  `verbosityLevel` = 3

    Parameters: | verbosityLevel (int) – Default logging verbosity level.

  `verbosityLabels` = (u'Critical', u'Error', u'Warning', u'Info', u'Debug')

    Parameters: | verbosityLabels (tuple) – Logging verbosity labels.

  `loggingDefaultFormatter` = u'Default'

    Parameters: | loggingDefaultFormatter (unicode) – Default logging formatter name.

  `loggingSeparators` = u'************************************************************************************************'

    Parameters: | loggingSeparators (unicode) – Logging separators.

  `defaultCodec` = 'utf-8'

    Parameters: | defaultCodec (unicode) – Default codec.

  `codecError` = 'ignore'

    Parameters: | codecError (unicode) – Default codec error behavior.

  `applicationDirectory` = u'Umbra/1.0'

    Parameters: | applicationDirectory (unicode) – Package Application directory.

  `providerDirectory` = u'HDRLabs'

    Parameters: | providerDirectory (unicode) – Package provider directory.

  `patchesDirectory` = u'patches'

    Parameters: | patchesDirectory (unicode) – Application patches directory.

  `settingsDirectory` = u'settings'

    Parameters: | settingsDirectory (unicode) – Application settings directory.

  `userComponentsDirectory` = u'components'

    Parameters: | userComponentsDirectory (unicode) – Application user components directory.

  `loggingDirectory` = u'logging'

    Parameters: | loggingDirectory (unicode) – Application logging directory.

  `ioDirectory` = u'io'

    Parameters: | ioDirectory (unicode) – Application io directory.

  `preferencesDirectories` = (u'patches', u'settings', u'components', u'logging', u'io')

    Parameters: | preferencesDirectories (tuple) – Application preferences directories.

  `factoryComponentsDirectory` = u'components/factory'

    Parameters: | factoryComponentsDirectory (unicode) – Application factory components directory.

  `factoryAddonsComponentsDirectory` = u'components/addons'

    Parameters: | factoryAddonsComponentsDirectory (unicode) – Application addons components directory.

  `resourcesDirectory` = u'resources'

    Parameters: | resourcesDirectory (unicode) – Application resources directory.

  `patchesFile` = u'Umbra_Patches.rc'

    Parameters: | patchesFile (unicode) – Application settings file.

  `settingsFile` = u'Umbra_Settings.rc'

    Parameters: | settingsFile (unicode) – Application settings file.

  `loggingFile` = u'Umbra_Logging_{0}.log'

    Parameters: | loggingFile (unicode) – Application logging file.

  `librariesDirectory` = u'libraries'

    Parameters: | librariesDirectory (unicode) – Application libraries directory.

  `defaultTimerCycle` = 125

    Parameters: | defaultTimerCycle (int) – Default timer cycle length in milliseconds.

  `nullObject` = u'None'

    Parameters: | nullObject (unicode) – Default null object string.